@@ -3,10 +3,7 @@ import pytest
 from sscutils.artifact_context import ArtifactContext
 from sscutils.exceptions import NotAnArtifactException
 from sscutils.utils import cd_into
-from sscutils.validation_functions import (
-    validate_repo_name,
-    validate_step_name,
-)
+from sscutils.validation_functions import is_repo_name, is_step_name
 
 
 @pytest.mark.parametrize(
@@ -22,10 +19,10 @@ from sscutils.validation_functions import (
 )
 def test_repo_name_valid(repo_name, is_valid):
     if is_valid:
-        validate_repo_name(repo_name)
+        is_repo_name(repo_name)
     else:
         with pytest.raises(NameError):
-            validate_repo_name(repo_name)
+            is_repo_name(repo_name)
 
 
 @pytest.mark.parametrize(
@@ -41,13 +38,18 @@ def test_repo_name_valid(repo_name, is_valid):
 )
 def test_step_name_valid(step_name, is_valid):
     if is_valid:
-        validate_step_name(step_name)
+        is_step_name(step_name)
     else:
         with pytest.raises(NameError):
-            validate_step_name(step_name)
+            is_step_name(step_name)
 
 
 def test_failing_config(tmp_path):
     with cd_into(tmp_path):
         with pytest.raises(NotAnArtifactException):
             ArtifactContext()
+
+
+def test_missing_fk(tmp_path):
+    # TODO
+    pass
