@@ -30,10 +30,11 @@ def log(msg, artifact_type):
     logger.info(f"validating {artifact_type} - {msg}")
 
 
-def sql_validation(constr, env=None):
-    loader = SqlLoader(constr, echo=False)
+def sql_validation(constr, env=None, draw=False, batch_size=2000):
+    loader = SqlLoader(constr, echo=False, batch_size=batch_size)
     loader.setup_schema()
-    dump_graph(loader.sql_meta, loader.engine)
+    if draw:
+        dump_graph(loader.sql_meta, loader.engine)
     try:
         loader.load_data(env)
         loader.validate_data(env)
@@ -58,7 +59,9 @@ def validate_project():
     _ = ProjectConfig()
 
 
-def validate_dataset(constr="sqlite:///:memory:", env=None):
+def validate_dataset(
+    constr="sqlite:///:memory:", env=None, draw=False, batch_size=2000
+):
     """asserts a few things about a dataset
 
     - configuration files are present
@@ -112,7 +115,7 @@ def validate_dataset(constr="sqlite:///:memory:", env=None):
     assert ds_atom_n == len(root_serialized_ns.atoms)
 
     _log("data can be read to sql db")
-    sql_validation(constr, env)
+    sql_validation(constr, env, draw, batch_size=batch_size)
 
     _log("data can be imported to a project via dvc")
     validate_ds_importable(env or COMPLETE_ENV_NAME)
